@@ -193,7 +193,9 @@ class PersistentContext(object):
 
 
   def __close_root_connection(self, status, T):
-    root_connection = getattr(T, self.__tag)
+    root_connection = getattr(T, self.__tag, None)
+    if root_connection is None: # already closed
+      return
     root_connection.close()
     delattr(T, self.__tag)
 
